@@ -35,6 +35,9 @@ HuHuCAR.sim = function(n = 1000, cov_num = 2, level_num = c(2, 2),
     stop("Length of omega must be equal to (cov_num + 2)!")
   }else if(is.null(omega)){
     omega = rep(1.0 / (cov_num + 2), times = 2 + cov_num);
+  }else if(sum(abs(omega)) == 0){
+    omega <- omega; 
+    warning("The procedure reduces to complete randomization!")
   }else{
     omega = abs(omega) / sum(abs(omega));
   }
@@ -52,21 +55,24 @@ HuHuCAR.sim = function(n = 1000, cov_num = 2, level_num = c(2, 2),
   assig_temp = CA[dim(CA)[1], ]; 
   R$assignments = LETTERS[assig_temp]; 
   
-  AS = RES[2, 1][[1]]; 
-  rownames(AS) = c(BBCDname(cov_num, "covariate"));
-  colnames(AS) = c(BBCDname(ncol(AS), "level"));
-  
+  AS0 = RES[2, 1][[1]];
+  AS0ordinPS = MVReturnM(PStrGen(cov_num, level_num), AS0)[, 1]; 
+  AS = AS0[, order(AS0ordinPS)]
+  rownames(AS) = BBCDname(cov_num, "covariate");
+  colnames(AS) = BBCDname(ncol(AS), "stratum");
   R$'All strata' = AS;
   
-  Df = RES[4, 1][[1]];
-  rownames(Df) = nameString(cov_num, level_num, ncol(AS), "All", AS);
+  strt_num = ncol(AS);
+  R$strt_num = strt_num;
   
-  R$Diff = t(Df);
+  Df0 = RES[4, 1][[1]]; 
+  Df = Df0[c(1, 1 + order(AS0ordinPS), (1 + strt_num + 1) : (1 + strt_num + sum(level_num))), ,drop = FALSE]
+  rownames(Df) = nameString(cov_num, level_num, ncol(AS), "All", AS);
+  R$Diff = Df;
   
   R$method = "Hu and Hu's General CAR";
   R$cov_num = cov_num;
   R$level_num = level_num;
-  R$strt_num = ncol(AS);
   R$N = n;
   R$weight = omega[3 : (2 + cov_num)];
   R$'Data Type' = "Simulated";
@@ -131,21 +137,24 @@ PocSimMIN.sim = function(n = 1000, cov_num = 2, level_num = c(2, 2),
   assig_temp = CA[dim(CA)[1], ]; 
   R$assignments = LETTERS[assig_temp]; 
   
-  AS = RES[2, 1][[1]]; 
-  rownames(AS) = c(BBCDname(cov_num, "covariate"));
-  colnames(AS) = c(BBCDname(ncol(AS), "level"));
-  
+  AS0 = RES[2, 1][[1]];
+  AS0ordinPS = MVReturnM(PStrGen(cov_num, level_num), AS0)[, 1]; 
+  AS = AS0[, order(AS0ordinPS)]
+  rownames(AS) = BBCDname(cov_num, "covariate");
+  colnames(AS) = BBCDname(ncol(AS), "stratum");
   R$'All strata' = AS;
   
-  Df = RES[4, 1][[1]];
-  rownames(Df) = nameString(cov_num, level_num, ncol(AS), "All", AS);
+  strt_num = ncol(AS);
+  R$strt_num = strt_num;
   
-  R$Diff = t(Df);
+  Df0 = RES[4, 1][[1]]; 
+  Df = Df0[c(1, 1 + order(AS0ordinPS), (1 + strt_num + 1) : (1 + strt_num + sum(level_num))), ,drop = FALSE]
+  rownames(Df) = nameString(cov_num, level_num, ncol(AS), "All", AS);
+  R$Diff = Df;
   
   R$method = "Pocock and Simon's Procedure with Two Arms";
   R$cov_num = cov_num;
   R$level_num = level_num;
-  R$strt_num = ncol(AS);
   R$N = n;
   R$weight = omega[3 : (2 + cov_num)];
   R$'Data Type' = "Simulated";
@@ -202,21 +211,24 @@ StrBCD.sim = function(n = 1000, cov_num = 2, level_num = c(2, 2),
   assig_temp = CA[dim(CA)[1], ]; 
   R$assignments = LETTERS[assig_temp]; 
   
-  AS = RES[2, 1][[1]]; 
-  rownames(AS) = c(BBCDname(cov_num, "covariate"));
-  colnames(AS) = c(BBCDname(ncol(AS), "level"));
-  
+  AS0 = RES[2, 1][[1]];
+  AS0ordinPS = MVReturnM(PStrGen(cov_num, level_num), AS0)[, 1]; 
+  AS = AS0[, order(AS0ordinPS)]
+  rownames(AS) = BBCDname(cov_num, "covariate");
+  colnames(AS) = BBCDname(ncol(AS), "stratum");
   R$'All strata' = AS;
   
-  Df = RES[4, 1][[1]];
-  rownames(Df) = nameString(cov_num, level_num, ncol(AS), "All", AS);
+  strt_num = ncol(AS);
+  R$strt_num = strt_num;
   
-  R$Diff = t(Df);
+  Df0 = RES[4, 1][[1]]; 
+  Df = Df0[c(1, 1 + order(AS0ordinPS), (1 + strt_num + 1) : (1 + strt_num + sum(level_num))), ,drop = FALSE]
+  rownames(Df) = nameString(cov_num, level_num, ncol(AS), "All", AS);
+  R$Diff = Df;
   
   R$method = "Shao's Procedure";
   R$cov_num = cov_num;
   R$level_num = level_num;
-  R$strt_num = ncol(AS);
   R$N = n;
   R$'Data Type' = "Simulated";
   R$framework = "Minimization/Stratified randomization"; 
@@ -266,16 +278,20 @@ StrPBR.sim = function(n = 1000, cov_num = 2, level_num = c(2, 2),
   assig_temp = CA[dim(CA)[1], ]; 
   R$assignments = LETTERS[assig_temp]; 
   
-  AS = RES[2, 1][[1]]; 
-  rownames(AS) = c(BBCDname(cov_num, "covariate"));
-  colnames(AS) = c(BBCDname(ncol(AS), "level"));
-  
+  AS0 = RES[2, 1][[1]];
+  AS0ordinPS = MVReturnM(PStrGen(cov_num, level_num), AS0)[, 1]; 
+  AS = AS0[, order(AS0ordinPS)]
+  rownames(AS) = BBCDname(cov_num, "covariate");
+  colnames(AS) = BBCDname(ncol(AS), "stratum");
   R$'All strata' = AS;
   
-  Df = RES[4, 1][[1]];
-  rownames(Df) = nameString(cov_num, level_num, ncol(AS), "All", AS);
+  strt_num = ncol(AS);
+  R$strt_num = strt_num;
   
-  R$Diff = t(Df);
+  Df0 = RES[4, 1][[1]]; 
+  Df = Df0[c(1, 1 + order(AS0ordinPS), (1 + strt_num + 1) : (1 + strt_num + sum(level_num))), ,drop = FALSE]
+  rownames(Df) = nameString(cov_num, level_num, ncol(AS), "All", AS);
+  R$Diff = Df;
   
   st_num = RES[1, 1][[1]];
   colnames(st_num) = BBCDname(ncol(AS), "level-");
@@ -285,7 +301,6 @@ StrPBR.sim = function(n = 1000, cov_num = 2, level_num = c(2, 2),
   R$method = "Stratified Permuted Block Randomization";
   R$cov_num = cov_num;
   R$level_num = level_num;
-  R$strt_num = ncol(AS);
   R$N = n;
   R$bsize = bsize;
   R$`Data Type` = "Simulated";
@@ -333,16 +348,20 @@ DoptBCD.sim = function(n = 1000, cov_num = 2, level_num = c(2, 2),
   assig_temp = CA[dim(CA)[1], ]; 
   R$assignments = LETTERS[assig_temp]; 
   
-  AS = RES[2, 1][[1]]; 
-  rownames(AS) = c(BBCDname(cov_num, "covariate"));
-  colnames(AS) = c(BBCDname(ncol(AS), "level"));
-  
+  AS0 = RES[2, 1][[1]];
+  AS0ordinPS = MVReturnM(PStrGen(cov_num, level_num), AS0)[, 1]; 
+  AS = AS0[, order(AS0ordinPS)]
+  rownames(AS) = BBCDname(cov_num, "covariate");
+  colnames(AS) = BBCDname(ncol(AS), "stratum");
   R$'All strata' = AS;
   
-  Df = RES[4, 1][[1]];
-  rownames(Df) = nameString(cov_num, level_num, ncol(AS), "All", AS); 
+  strt_num = ncol(AS);
+  R$strt_num = strt_num;
   
-  R$Diff = t(Df);
+  Df0 = RES[4, 1][[1]]; 
+  Df = Df0[c(1, 1 + order(AS0ordinPS), (1 + strt_num + 1) : (1 + strt_num + sum(level_num))), ,drop = FALSE]
+  rownames(Df) = nameString(cov_num, level_num, ncol(AS), "All", AS);
+  R$Diff = Df;
   
   R$method = "Atkinson's Optimum Biased Coin Design with Two Arms";
   R$cov_num = cov_num;
@@ -436,7 +455,7 @@ DoptBCD.sim = function(n = 1000, cov_num = 2, level_num = c(2, 2),
 #                                pr = rep(0.5, 4), a = 2.0) UseMethod("carandom")
 
 AdjBCD.sim = function(n = 1000, cov_num = 2, level_num = c(2, 2), 
-                      pr = rep(0.5, 4), a = 2.0){
+                      pr = rep(0.5, 4), a = 3.0){
   if(length(level_num) != cov_num){
     stop("Length of level_num must be equal to cov_num !")
   }
@@ -473,20 +492,24 @@ AdjBCD.sim = function(n = 1000, cov_num = 2, level_num = c(2, 2),
   assig_temp = CA[dim(CA)[1], ]; 
   R$assignments = LETTERS[assig_temp]; 
   
-  AS = RES[2, 1][[1]]; 
-  rownames(AS) = c(BBCDname(cov_num, "covariate"));
-  colnames(AS) = c(BBCDname(ncol(AS), "level"));
-  
+  AS0 = RES[2, 1][[1]];
+  AS0ordinPS = MVReturnM(PStrGen(cov_num, level_num), AS0)[, 1]; 
+  AS = AS0[, order(AS0ordinPS)]
+  rownames(AS) = BBCDname(cov_num, "covariate");
+  colnames(AS) = BBCDname(ncol(AS), "stratum");
   R$'All strata' = AS;
   
-  Df = RES[4, 1][[1]];
+  strt_num = ncol(AS);
+  R$strt_num = strt_num;
+  
+  Df0 = RES[4, 1][[1]]; 
+  Df = Df0[c(1, 1 + order(AS0ordinPS), (1 + strt_num + 1) : (1 + strt_num + sum(level_num))), ,drop = FALSE]
   rownames(Df) = nameString(cov_num, level_num, ncol(AS), "All", AS);
-  R$Diff = t(Df);
+  R$Diff = Df;
   
   R$method = "Covariate-adaptive Biased Coin Design with Two Arms";
   R$cov_num = cov_num;
   R$level_num = level_num;
-  R$strt_num = ncol(AS);
   R$N = n;
   R$'Data Type' = "Simulated";
   R$framework = "Stratified randomization"; 
